@@ -185,9 +185,10 @@ OC.L10N.register(
     "Members" : "Členovia",
     "Upload new files" : "Nahrať nové súbory",
     "Share from Files" : "Zdieľať zo Súborov",
+    "Pending share" : "Čakajúce zdeľanie",
     "Add this attachment" : "Pridať túto prílohu",
     "Show in Files" : "Zobraziť v Súboroch",
-    "Unshare file" : "Nezdieľať súbor",
+    "Remove attachment" : "Odstrániť prílohu",
     "Delete Attachment" : "Odstrániť prílohu",
     "Restore Attachment" : "Obnoviť prílohu",
     "File to share" : "Súbor na zdieľanie",
