@@ -185,9 +185,10 @@ OC.L10N.register(
     "Members" : "成员",
     "Upload new files" : "上传新文件",
     "Share from Files" : "从文件共享",
+    "Pending share" : "待分享",
     "Add this attachment" : "添加此附件",
     "Show in Files" : "在文件中显示",
-    "Unshare file" : "取消分享文件",
+    "Remove attachment" : "删除附件",
     "Delete Attachment" : "删除附件",
     "Restore Attachment" : "恢复附件",
     "File to share" : "要分享的文件",
