@@ -185,9 +185,10 @@ OC.L10N.register(
     "Members" : "成員",
     "Upload new files" : "上傳新檔案",
     "Share from Files" : "從檔案進行分享",
+    "Pending share" : "等待分享",
     "Add this attachment" : "添加此附件",
     "Show in Files" : "顯示在檔案中",
-    "Unshare file" : "取消分享檔案",
+    "Remove attachment" : "移除附件",
     "Delete Attachment" : "刪除附件",
     "Restore Attachment" : "恢復附件",
     "File to share" : "要分享的檔案",
